# pg-data-etl

ETL tools for postgres data, built on top of the `psql` and `pg_dump` command line tools.

## Python environment

Use `conda` to create a virtual environment:

```bash
cd ~./Documents/GitHub/pg-data-etl
conda env create -f env.yml
```
